[![Coverage Status](https://coveralls.io/repos/github/Luindil/Glassure/badge.svg?branch=develop)](https://coveralls.io/github/Luindil/Glassure?branch=develop)
[![DOI](https://zenodo.org/badge/24698239.svg)](https://zenodo.org/badge/latestdoi/24698239)

# Glassure


An API and GUI program for data analysis of total x-ray diffraction data.
It performs background subtraction, Fourier transform and optimization of
experimental data.

## Maintainer

Clemens Prescher (clemens.prescher@gmail.com)

## Requirements

- python 3.8+

It is known to run on Windows, Mac OS X and Linux.

## Installation

The Glassure package can be installed into your existing python distribution using pypi via:

```bash
python -m pip install glassure
```

The graphical user interface for Glassure can then be started from by typing
```bash
glassure
```

if you want to make a shortcut for the desktop, the glassure executable can be found in the 
python scripts folder.  




